==> cybop-0.20.0.tar.gz: cybop-0.20.0-Linux/src/variable/type_size/thread_type_size.c <==
/*
 * Copyright (C) 1999-2018. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.20.0 2018-06-30
 * @author Christian Heller <christian.heller@cybop.org>
 */

#ifndef THREAD_TYPE_SIZE_SOURCE
#define THREAD_TYPE_SIZE_SOURCE

//
// The global variables.
//
// CAUTION! This is just the variable definition.
// Initialisation happens in directory "controller/globaliser/".
//

/** The pthread_t thread type size. */
static int THREAD_TYPE_SIZE_ARRAY[1];
static int* THREAD_TYPE_SIZE = THREAD_TYPE_SIZE_ARRAY;

/** The pthread_mutex_t thread type size. */
static int MUTEX_THREAD_TYPE_SIZE_ARRAY[1];
static int* MUTEX_THREAD_TYPE_SIZE = MUTEX_THREAD_TYPE_SIZE_ARRAY;

/* THREAD_TYPE_SIZE_SOURCE */
#endif

==> cybop-0.22.0.tar.gz: cybop-0.22.0-Linux/src/variable/type_size/thread_type_size.c <==
/*
 * Copyright (C) 1999-2022. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.22.0 2022-02-22
 * @author Christian Heller <christian.heller@cybop.org>
 */

#ifndef THREAD_TYPE_SIZE_SOURCE
#define THREAD_TYPE_SIZE_SOURCE

//
// The global variables.
//
// CAUTION! This is just the variable definition.
// Initialisation happens in directory "controller/globaliser/".
//

/** The identification thread type size. */
static int IDENTIFICATION_THREAD_TYPE_SIZE_ARRAY[1];
static int* IDENTIFICATION_THREAD_TYPE_SIZE = IDENTIFICATION_THREAD_TYPE_SIZE_ARRAY;

/** The mutex thread type size. */
static int MUTEX_THREAD_TYPE_SIZE_ARRAY[1];
static int* MUTEX_THREAD_TYPE_SIZE = MUTEX_THREAD_TYPE_SIZE_ARRAY;

/* THREAD_TYPE_SIZE_SOURCE */
#endif
